# Copyright  2016-2022 Maël Azimi <m.a@moul.re>
#
# Silkaj is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Silkaj is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Silkaj. If not, see <https://www.gnu.org/licenses/>.

import webbrowser
from pathlib import Path
from unittest.mock import patch

import pytest
from click.testing import CliRunner

from silkaj import cli, license
from silkaj.constants import SUCCESS_EXIT_STATUS


def test_license_approval_g1_test(capsys):
    license.license_approval("g1-test")
    assert not capsys.readouterr().out


# TODO: approve is not tested
@pytest.mark.parametrize(
    "display, approve",
    [
        (True, True),
        (True, False),
        (False, True),
        (False, False),
    ],
)
@patch("click.confirm")
@patch.object(license, "display_license")
def test_license_approval_g1(mock_display_license, mock_confirm, display, approve):
    # https://stackoverflow.com/a/62939130
    mock_confirm.return_value = display
    license.license_approval("g1")
    if display:
        mock_display_license.assert_called_once()
    mock_confirm.assert_called()


@pytest.mark.parametrize(
    "language, web, license_sample",
    [
        ("en", False, "**Currency licensing"),
        ("fr", False, "**Licence de la monnaie"),
        ("en", True, "**Currency licensing"),
        ("fr", True, "**Licence de la monnaie"),
    ],
)
@patch("webbrowser.open")
def test_display_license(webbrowser_open, language, web, license_sample):
    args = []
    if web:
        args += ["--g1-license-web"]
    args += ["license"]

    result = CliRunner().invoke(cli.cli, args=args, input=language)
    assert "In which language" in result.output
    if web and license.has_web_browser():
        webbrowser_open.assert_called_once_with(license.licenses_urls[language])
    else:
        assert license_sample in result.output
    assert result.exit_code == SUCCESS_EXIT_STATUS


def test_has_web_browser():
    """
    https://stackoverflow.com/a/50990039
    """
    with patch("webbrowser.get", side_effect=webbrowser.Error):
        assert license.has_web_browser() == False

    with patch("webbrowser.get", side_effect=None):
        assert license.has_web_browser() == True


@pytest.mark.parametrize(
    "language, license_sample",
    [
        ("en", "**Currency licensing"),
        ("", "**Currency licensing"),
        ("fr", "**Licence de la monnaie"),
        ("blabla", ""),
    ],
)
def test_language_prompt(language, license_sample):
    result = CliRunner().invoke(cli.cli, args=["license"], input=language)
    assert "In which language" in result.output
    assert license_sample in result.output
    assert result.exit_code == SUCCESS_EXIT_STATUS


def test_license_path():
    for lang in license.languages:
        assert license.license_path(lang).is_file()
